@@ -86,7 +86,7 @@
 #define KNOTIFICATIONS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KNOTIFICATIONS_NO_DEPRECATED
-#  define KNOTIFICATIONS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54900
+#  define KNOTIFICATIONS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55000
 #endif
 #ifdef KNOTIFICATIONS_NO_DEPRECATED_WARNINGS
 #  define KNOTIFICATIONS_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KNOTIFICATIONS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KNOTIFICATIONS_DEPRECATED_WARNINGS_SINCE KNOTIFICATIONS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KNOTIFICATIONS_DEPRECATED_WARNINGS_SINCE 0x54900
+#    define KNOTIFICATIONS_DEPRECATED_WARNINGS_SINCE 0x55000
 #  endif
 #endif
 
@@ -115,6 +115,24 @@
 #else
 #  define KNOTIFICATIONS_DEPRECATED_VERSION_5_67(text)
 #endif
+
+#if KNOTIFICATIONS_DEPRECATED_WARNINGS_SINCE >= 0x54b00
+#  define KNOTIFICATIONS_DEPRECATED_VERSION_5_75(text) KNOTIFICATIONS_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KNOTIFICATIONS_DEPRECATED_VERSION_5_75(text)
+#endif
+
+#if KNOTIFICATIONS_DEPRECATED_WARNINGS_SINCE >= 0x54c00
+#  define KNOTIFICATIONS_DEPRECATED_VERSION_5_76(text) KNOTIFICATIONS_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KNOTIFICATIONS_DEPRECATED_VERSION_5_76(text)
+#endif
+
+#if KNOTIFICATIONS_DEPRECATED_WARNINGS_SINCE >= 0x54f00
+#  define KNOTIFICATIONS_DEPRECATED_VERSION_5_79(text) KNOTIFICATIONS_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KNOTIFICATIONS_DEPRECATED_VERSION_5_79(text)
+#endif
 #define KNOTIFICATIONS_DEPRECATED_VERSION_5(minor, text)      KNOTIFICATIONS_DEPRECATED_VERSION_5_##minor(text)
 #define KNOTIFICATIONS_DEPRECATED_VERSION(major, minor, text) KNOTIFICATIONS_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KNOTIFICATIONS_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KNOTIFICATIONS_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
